@@ -13,7 +13,7 @@ parser.add_argument("-x", "--index", help="Page number at which pages should be
 parser.add_argument("-rm", "--remove", nargs="+", type=int, help="Removes the pages given from the PDF specified")      # Flag to remove pages
 parser.add_argument("-g", "--get", nargs="+", type=int, help="Outputs the pages given from the PDF specified")      # Flag to get pages
 parser.add_argument("-i", "--input", default="./", help="Path to pages, defaults to current directory. Can be a direct path to a file")      # Our input and output is the current directory by default
-parser.add_argument("-o", "--output", default="./", help="Path to where you want the papers saved, defaults to current directory")
+parser.add_argument("-o", "--output", default="./", help="Path to where you want the papers saved, defaults to current directory. Can be a direct path to a file")
 parser.add_argument("-aa", "--autoarticle", nargs="?", const="40", help="Creates a new article in .txt format at the output based on the PDF(s) and .txt-documents in the input of this length (sentances). Defaults to 40. Will save extracted text from PDF(s) as a .txt file in output directory")    # Const är vad det får om man ej anger det
 
 args = parser.parse_args()      # Collects our input in args
@@ -93,8 +93,8 @@ def create_print_version(pages_in):
     if args.force:
         pages_out += pages_in
     
-    # Where it should be -> which pages are added -> write
-    PdfWriter(args.output + "/" + "print.pdf").addpages(pages_out).write()
+    write_pdf(pages_out, "print.pdf")
+
 # Sök Diod
 def create_web_version(pages_in):
     """Puts together the pages in pages_in to a single PDF in
@@ -106,8 +106,8 @@ def create_web_version(pages_in):
     # We put in the pages one after the other
     while len(pages_in) > 0:
         pages_out.append(pages_in.pop(0))
-        
-    PdfWriter(args.output + "/" + "web.pdf").addpages(pages_out).write()
+
+    write_pdf(pages_out, "web.pdf")
 
 def print_to_web(pages_in):
     """Converts the pages in pages_in from print format to web format and
@@ -131,8 +131,7 @@ def print_to_web(pages_in):
         pages_out_sorted2.insert(0, pages_out.pop(0))
 
     pages_out_sorted1.extend(pages_out_sorted2)     # The content of the second list is added to the first
-
-    PdfWriter(args.output + "/split.pdf").addpages(pages_out_sorted1).write()
+    write_pdf(pages_out_sorted1, "split.pdf")
 
 def fixpage(*pages):
     """ Taken from example project in pdfrw.
@@ -165,7 +164,7 @@ def remove_pages(pages_in, page_numbers):
         else:
             del pages_out[index] 
             i-=-1
-    PdfWriter(args.output + "/removed.pdf").addpages(pages_out).write()
+    write_pdf(pages_out, "removed.pdf")
 
 def insert_pages(pages_in, pages_to_be_inserted, index):
     """ Inserts pages at specified index
@@ -176,12 +175,16 @@ def insert_pages(pages_in, pages_to_be_inserted, index):
 
     while len(pages_to_be_inserted) > 0:
         pages_out.insert(true_index, pages_to_be_inserted.pop(0))
-    PdfWriter(args.output + "/inserted.pdf").addpages(pages_out).write()
+    write_pdf(pages_out, "inserted.pdf")
 
 def get_pages(pages_in, page_numbers):
     """ Creates a separate PDF file for each
     page as listed in page_numbers
     """
+    if not os.path.isdir(args.output):
+        print("When using --get, output must be a directory. Exiting...")
+        exit()
+
     for nbr in page_numbers:
         nbr = nbr - 1       # pages_in starts indexing at 0, user at 1
         if (nbr < 0) or (nbr > len(pages_in) - 1):
@@ -196,6 +199,10 @@ def create_article(path, length):
     """ Creates a new article using Markov chains based on the PDF(s) and .txt(s)
     at path, and with length number of sentances
     """
+    if not os.path.isdir(args.output):
+        print("When using --autoarticle, --output must be a directory. Exiting...")
+        exit()
+
     paths = []
 
     if os.path.isdir(path):     # If we have a directory
@@ -240,7 +247,17 @@ def create_article(path, length):
 
     del aa  # Remove the damn object
 
-
+def write_pdf(pages, default_name):
+    """Writes pdf from pages, either to default name or to a specific path if one is defined
+    in args.output
+    """
+    if os.path.isdir(args.output):
+        # Where it should be -> which pages are added -> write
+        PdfWriter(args.output + "/" + default_name).addpages(pages).write()
+    else:
+        if not args.output.endswith(".pdf"):    # File must be a PDF
+            args.output = args.output + ".pdf"
+        PdfWriter(args.output).addpages(pages).write()
 
 # End of defining functions
 
